"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Endpoint = void 0;
const lisk_sdk_1 = require("lisk-sdk");
const schemas_1 = require("./schemas");
const validator = lisk_sdk_1.validator.validator;
const { encrypt, legacy } = lisk_sdk_1.cryptography;
class Endpoint extends lisk_sdk_1.BasePluginEndpoint {
    init(state, config) {
        this._state = state;
        this._config = config;
    }
    async authorize(context) {
        validator.validate(schemas_1.actionParamsSchema, context.params);
        const { enable, password } = context.params;
        try {
            const parsedEncryptedPassphrase = encrypt.parseEncryptedMessage(this._config.encryptedPassphrase);
            const passphrase = await encrypt.decryptMessageWithPassword(parsedEncryptedPassphrase, password, 'utf-8');
            const { publicKey, privateKey } = legacy.getPrivateAndPublicKeyFromPassphrase(passphrase);
            this._state.publicKey = enable ? publicKey : undefined;
            this._state.privateKey = enable ? privateKey : undefined;
            const changedState = enable ? 'enabled' : 'disabled';
            return {
                result: `Successfully ${changedState} the reporting of misbehavior.`,
            };
        }
        catch (error) {
            throw new Error('Password given is not valid.');
        }
    }
}
exports.Endpoint = Endpoint;
//# sourceMappingURL=endpoint.js.map